==> nextcloud-26.0.10.tgz: nextcloud/apps/user_status/l10n/pt_PT.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "No recent status changes" : "Sem alterações de estado recentes",
    "In a meeting" : "Numa reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Working remotely" : "A trabalhar à distância",
    "In a call" : "Numa chamada",
    "User status" : "Estado do utilizador",
    "Clear status after" : "Limpar mensagem de estado após",
    "What is your status?" : "Qual é o seu estado?",
    "Set status" : "Definir estado",
    "Online status" : "Estado online",
    "Status message" : "Mensagem de estado",
    "Clear status message" : "Limpar mensagem de estado",
    "Set status message" : "Definir mensagem de estado",
    "There was an error saving the status" : "Ocorreu um erro ao guardar o estado",
    "There was an error clearing the status" : "Ocorreu um erro ao apagar o estado",
    "Don't clear" : "Não apagar",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Away" : "Ausente",
    "Do not disturb" : "Não incomodar",
    "Invisible" : "Invisível ",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao guardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Desativar todas as notificações",
    "Appear offline" : "Aparecer offline",
    "View profile" : "Visualizar perfil",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.7.tgz: nextcloud/apps/user_status/l10n/pt_PT.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Estados recentes",
    "No recent status changes" : "Sem alterações de estado recentes",
    "In a meeting" : "Numa reunião",
    "Commuting" : "Em trânsito",
    "Out sick" : "Doente",
    "Vacationing" : "Férias",
    "Out of office" : "Fora do escritório",
    "Working remotely" : "A trabalhar à distância",
    "In a call" : "Numa chamada",
    "User status" : "Estado do utilizador",
    "Clear status after" : "Limpar mensagem de estado após",
    "What is your status?" : "Qual é o seu estado?",
    "Set status" : "Definir estado",
    "Online status" : "Estado online",
    "Status message" : "Mensagem de estado",
    "Clear status message" : "Limpar mensagem de estado",
    "Set status message" : "Definir mensagem de estado",
    "There was an error saving the status" : "Ocorreu um erro ao guardar o estado",
    "There was an error clearing the status" : "Ocorreu um erro ao apagar o estado",
    "Don't clear" : "Não apagar",
    "Today" : "Hoje",
    "This week" : "Esta semana",
    "Online" : "Online",
    "Away" : "Ausente",
    "Do not disturb" : "Não incomodar",
    "Invisible" : "Invisível ",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Ocorreu um erro ao guardar o novo estado",
    "30 minutes" : "30 minutos",
    "1 hour" : "1 hora",
    "4 hours" : "4 horas",
    "Mute all notifications" : "Desativar todas as notificações",
    "Appear offline" : "Aparecer offline",
    "View profile" : "Visualizar perfil"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
